import React, { useState, useEffect } from 'react'
import Taro from '@tarojs/taro'
import { useModel } from '@/store'
import { Text } from '@tarojs/components'
import Spin from '@/components/Spin'
import GetUserPhone from '@/components/GetUserPhone/index'
import GetUserIcon from '@/components/GetUserIcon/index'
import AddYeZhuRenZheng from '@/components/AddYeZhuRenZheng'
import useMountTrack from '@/utils/hooks/useMountTrack'
import request, { apis } from '@/utils/request'
import { getPage } from '@/utils'
import './index.less'

const pages = require('../pages')

const showError = err => {
  Taro.showModal({
    title: '错误',
    content: err,
    showCancel: false
  })
}

export default function (props) {
  const [showAuthBasic, setShowAuthBasic] = useState(false)
  const [showAuthYeZhu, setShowAuthYeZhu] = useState(false)
  const [showAuthPhone, setShowAuthPhone] = useState(false)
  const [ShowAdvLayer, setShowAdvLayer] = useState(true)
  const [AdvDetail, setShowAdvDetail] = useState(null)
  const [ShowAddLayer, setShowAddLayer] = useState(false)
  const { user, setUser } = useModel('user')

  const loading = !user || !user.personId
  const isAuthedBasic = user && user.avatarurl && user.nickname
  const isAuthedPhone = user && user.phone
  const isAuthedYeZhu = user

  const page = getPage()
  const needAuthBasic = (page.auth || []).indexOf('avatar') > -1
  const needAuthYeZhu = (page.auth || []).indexOf('yezhu') > -1
  const needAuthPhone = (page.auth || []).indexOf('phone') > -1

  useEffect(() => {
    if (user !== null && user.FirstComing !== undefined && user.FirstComing) {
      request({ ...apis.getIndexAdv, params: { showType: `screen`, showPosition: `index` } }).then((res) => {
        if (res !== null && res.length > 0) {
          setShowAdvDetail(res[0])
          setUser({ ...user, ShowIndexAdv: true, FirstComing: false })
        }
      })
    }
  }, [user])

  // 埋点
  useMountTrack()

  // 授权手机
  useEffect(() => {
    if (!isAuthedPhone && needAuthPhone) {
      setShowAuthPhone(true)
    } else {
      setShowAuthPhone(false)
    }
  }, [isAuthedPhone, needAuthPhone])

  // 认证业主
  useEffect(() => {
    // 如果当前是认证业务页面
    if (page.isYeZhuRenZheng) {
      return
    }

    if (isAuthedPhone && !isAuthedYeZhu) {
      const renZhengPage = pages.filter(x => x.isYeZhuRenZheng)[0]
      if (renZhengPage) {
        // 跳转到业主认证页面
        // to = renZhengPage.page
      }
    }
  }, [needAuthYeZhu, isAuthedPhone, page])

  // 授权头像
  useEffect(() => {
    let needShow = false

    // 授权手机之后才授权头像
    if (isAuthedPhone) {
      // 要求业主认证的
      if (isAuthedYeZhu || !needAuthYeZhu) {
        if (!isAuthedBasic && needAuthBasic) {
          needShow = true
        }
      }
    }

    setShowAuthBasic(needShow)
  }, [isAuthedBasic, needAuthBasic, isAuthedPhone, isAuthedYeZhu, needAuthYeZhu])

  const AdvClick = () => { // 首页弹窗点击事件
    setShowAdvLayer(false)
    if (AdvDetail.contentType === 'news') {
      Taro.navigateTo({ url: `/pages/HuoDong/ZiXunDetail/index?id=${AdvDetail.contentId}` })
    } else if (AdvDetail.contentType === 'tpNews') {
      Taro.navigateTo({ url: `/pages/WuYe/FuWuDetail/index?id=${AdvDetail.contentId}` })
    } else if (AdvDetail.contentType === 'notice') {
      Taro.navigateTo({ url: `/pages/WuYe/GongGaoDetail/index?id=${AdvDetail.contentId}` })
    } else if (AdvDetail.contentType === 'activity') {
      Taro.navigateTo({ url: `/pages/HuoDong/HuoDongDetail/index?id=${AdvDetail.contentId}` })
    }
  }

  return (
    <Spin loading={loading}>

      <view className={ShowAddLayer ? 'AddRenZhengLayer active' : 'AddRenZhengLayer'}>
        <view className='centerLabel'>
          <view>
            <scroll-view scroll-y='true'>
              {
                ShowAddLayer &&
                <AddYeZhuRenZheng Close={() => { setShowAddLayer(false) }}></AddYeZhuRenZheng>
              }
            </scroll-view>
          </view>
        </view>
      </view>

      {/* 广告 */}
      <view className='AdvLayer' style={{ display: user !== null && user.ShowIndexAdv !== undefined && user.ShowIndexAdv ? 'block' : 'none' }}>
        <view className='centerLabel'>
          <image mode='aspectFit' src={AdvDetail !== null ? AdvDetail.image : null} onClick={AdvClick}></image>
          <Text className='iconfont iconguanbi' onClick={() => { setUser({ ...user, ShowIndexAdv: false }) }}></Text>
        </view>
      </view>

      <GetUserIcon visible={showAuthBasic} onError={err => showError(`授权头像失败: ${err}`)} />
      <GetUserPhone visible={showAuthPhone} onError={err => showError(`授权手机失败: ${err}`)} />
      {
        props.children
      }
    </Spin>
  )
}
